@@ -27,13 +27,16 @@ constexpr unsigned API_VERSION_2_1 = ZIMG_MAKE_API_VERSION(2, 1);
 constexpr unsigned API_VERSION_2_2 = ZIMG_MAKE_API_VERSION(2, 2);
 
 #define API_VERSION_ASSERT(x) zassert_d((x) >= API_VERSION_2_0, "API version invalid")
-#define POINTER_ALIGNMENT_ASSERT(x) zassert_d(!(x) || reinterpret_cast<uintptr_t>(x) % zimg::ALIGNMENT == 0, "pointer not aligned")
-#define STRIDE_ALIGNMENT_ASSERT(x) zassert_d(!(x) || (x) % zimg::ALIGNMENT == 0, "buffer stride not aligned")
+#define POINTER_ALIGNMENT_ASSERT(x) zassert_d(!(x) || reinterpret_cast<uintptr_t>(x) % zimg::ALIGNMENT_RELAXED == 0, "pointer not aligned")
+#define STRIDE_ALIGNMENT_ASSERT(x) zassert_d(!(x) || (x) % zimg::ALIGNMENT_RELAXED == 0, "buffer stride not aligned")
+
+#define POINTER_ALIGNMENT64_ASSERT(x) zassert_d(!(x) || reinterpret_cast<uintptr_t>(x) % zimg::ALIGNMENT == 0, "pointer not aligned")
+#define STRIDE_ALIGNMENT64_ASSERT(x) zassert_d(!(x) || (x) % zimg::ALIGNMENT == 0, "buffer stride not aligned")
 
 thread_local zimg_error_code_e g_last_error = ZIMG_ERROR_SUCCESS;
 thread_local std::string g_last_error_msg;
 
-constexpr unsigned VERSION_INFO[] = { 2, 5, 0 };
+constexpr unsigned VERSION_INFO[] = { 2, 7, 5 };
 
 
 template <class T, class U>
@@ -126,20 +129,23 @@ zimg::CPUClass translate_cpu(zimg_cpu_type_e cpu)
 {
 	using zimg::CPUClass;
 
-	static const zimg::static_map<zimg_cpu_type_e, CPUClass, 12> map{
-		{ ZIMG_CPU_NONE,      CPUClass::NONE },
-		{ ZIMG_CPU_AUTO,      CPUClass::AUTO },
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_cpu_type_e, CPUClass, 15> map{
+		{ ZIMG_CPU_NONE,           CPUClass::NONE },
+		{ ZIMG_CPU_AUTO,           CPUClass::AUTO },
+		{ ZIMG_CPU_AUTO_64B,       CPUClass::AUTO_64B },
 #ifdef ZIMG_X86
-		{ ZIMG_CPU_X86_MMX,   CPUClass::NONE },
-		{ ZIMG_CPU_X86_SSE,   CPUClass::X86_SSE },
-		{ ZIMG_CPU_X86_SSE2,  CPUClass::X86_SSE2 },
-		{ ZIMG_CPU_X86_SSE3,  CPUClass::X86_SSE2 },
-		{ ZIMG_CPU_X86_SSSE3, CPUClass::X86_SSE2 },
-		{ ZIMG_CPU_X86_SSE41, CPUClass::X86_SSE2 },
-		{ ZIMG_CPU_X86_SSE42, CPUClass::X86_SSE2 },
-		{ ZIMG_CPU_X86_AVX,   CPUClass::X86_AVX },
-		{ ZIMG_CPU_X86_F16C,  CPUClass::X86_F16C },
-		{ ZIMG_CPU_X86_AVX2,  CPUClass::X86_AVX2 },
+		{ ZIMG_CPU_X86_MMX,        CPUClass::NONE },
+		{ ZIMG_CPU_X86_SSE,        CPUClass::X86_SSE },
+		{ ZIMG_CPU_X86_SSE2,       CPUClass::X86_SSE2 },
+		{ ZIMG_CPU_X86_SSE3,       CPUClass::X86_SSE2 },
+		{ ZIMG_CPU_X86_SSSE3,      CPUClass::X86_SSE2 },
+		{ ZIMG_CPU_X86_SSE41,      CPUClass::X86_SSE2 },
+		{ ZIMG_CPU_X86_SSE42,      CPUClass::X86_SSE2 },
+		{ ZIMG_CPU_X86_AVX,        CPUClass::X86_AVX },
+		{ ZIMG_CPU_X86_F16C,       CPUClass::X86_F16C },
+		{ ZIMG_CPU_X86_AVX2,       CPUClass::X86_AVX2 },
+		{ ZIMG_CPU_X86_AVX512F,    CPUClass::X86_AVX2 },
+		{ ZIMG_CPU_X86_AVX512_SKL, CPUClass::X86_AVX512 },
 #endif
 	};
 	return search_enum_map(map, cpu, "unrecognized cpu type");
@@ -149,7 +155,7 @@ zimg::PixelType translate_pixel_type(zimg_pixel_type_e pixel_type)
 {
 	using zimg::PixelType;
 
-	static const zimg::static_map<zimg_pixel_type_e, zimg::PixelType, 4> map{
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_pixel_type_e, zimg::PixelType, 4> map{
 		{ ZIMG_PIXEL_BYTE,  PixelType::BYTE },
 		{ ZIMG_PIXEL_WORD,  PixelType::WORD },
 		{ ZIMG_PIXEL_HALF,  PixelType::HALF },
@@ -160,7 +166,7 @@ zimg::PixelType translate_pixel_type(zimg_pixel_type_e pixel_type)
 
 bool translate_pixel_range(zimg_pixel_range_e range)
 {
-	static const zimg::static_map<zimg_pixel_range_e, bool, 2> map{
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_pixel_range_e, bool, 2> map{
 		{ ZIMG_RANGE_LIMITED, false },
 		{ ZIMG_RANGE_FULL,    true },
 	};
@@ -171,10 +177,10 @@ zimg::graph::GraphBuilder::ColorFamily translate_color_family(zimg_color_family_
 {
 	using zimg::graph::GraphBuilder;
 
-	static const zimg::static_map<zimg_color_family_e,GraphBuilder::ColorFamily, 3> map{
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_color_family_e, GraphBuilder::ColorFamily, 3> map{
 		{ ZIMG_COLOR_GREY, GraphBuilder::ColorFamily::GREY },
 		{ ZIMG_COLOR_RGB,  GraphBuilder::ColorFamily::RGB },
-		{ ZIMG_COLOR_YUV,  GraphBuilder::ColorFamily::YUV},
+		{ ZIMG_COLOR_YUV,  GraphBuilder::ColorFamily::YUV },
 	};
 	return search_enum_map(map, family, "unrecognized color family");
 }
@@ -183,7 +189,7 @@ zimg::graph::GraphBuilder::FieldParity translate_field_parity(zimg_field_parity_
 {
 	using zimg::graph::GraphBuilder;
 
-	static const zimg::static_map<zimg_field_parity_e, GraphBuilder::FieldParity, 3> map{
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_field_parity_e, GraphBuilder::FieldParity, 3> map{
 		{ ZIMG_FIELD_PROGRESSIVE, GraphBuilder::FieldParity::PROGRESSIVE },
 		{ ZIMG_FIELD_TOP,         GraphBuilder::FieldParity::TOP },
 		{ ZIMG_FIELD_BOTTOM,      GraphBuilder::FieldParity::BOTTOM },
@@ -196,7 +202,20 @@ std::pair<zimg::graph::GraphBuilder::ChromaLocationW, zimg::graph::GraphBuilder:
 	typedef zimg::graph::GraphBuilder::ChromaLocationW ChromaLocationW;
 	typedef zimg::graph::GraphBuilder::ChromaLocationH ChromaLocationH;
 
+	// VS 2017 miscompiles this.
+#ifdef _MSC_VER
 	static const zimg::static_map<zimg_chroma_location_e, std::pair<ChromaLocationW, ChromaLocationH>, 6> map{
+#else
+	// Workaround for std::pair assignment operator missing constexpr.
+	struct chroma_pair {
+		ChromaLocationW first;
+		ChromaLocationH second;
+
+		operator std::pair<ChromaLocationW, ChromaLocationH>() const { return{ first, second }; }
+	};
+
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_chroma_location_e, chroma_pair, 6> map{
+#endif
 		{ ZIMG_CHROMA_LEFT,        { ChromaLocationW::LEFT,   ChromaLocationH::CENTER } },
 		{ ZIMG_CHROMA_CENTER,      { ChromaLocationW::CENTER, ChromaLocationH::CENTER } },
 		{ ZIMG_CHROMA_TOP_LEFT,    { ChromaLocationW::LEFT,   ChromaLocationH::TOP } },
@@ -211,15 +230,20 @@ zimg::colorspace::MatrixCoefficients translate_matrix(zimg_matrix_coefficients_e
 {
 	using zimg::colorspace::MatrixCoefficients;
 
-	static const zimg::static_map<zimg_matrix_coefficients_e, zimg::colorspace::MatrixCoefficients, 8> map{
-		{ ZIMG_MATRIX_RGB,         MatrixCoefficients::RGB },
-		{ ZIMG_MATRIX_709,         MatrixCoefficients::REC_709 },
-		{ ZIMG_MATRIX_UNSPECIFIED, MatrixCoefficients::UNSPECIFIED },
-		{ ZIMG_MATRIX_470BG,       MatrixCoefficients::REC_601 },
-		{ ZIMG_MATRIX_170M,        MatrixCoefficients::REC_601 },
-		{ ZIMG_MATRIX_YCGCO,       MatrixCoefficients::YCGCO },
-		{ ZIMG_MATRIX_2020_NCL,    MatrixCoefficients::REC_2020_NCL },
-		{ ZIMG_MATRIX_2020_CL,     MatrixCoefficients::REC_2020_CL },
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_matrix_coefficients_e, zimg::colorspace::MatrixCoefficients, 13> map{
+		{ ZIMG_MATRIX_RGB,                      MatrixCoefficients::RGB },
+		{ ZIMG_MATRIX_709,                      MatrixCoefficients::REC_709 },
+		{ ZIMG_MATRIX_UNSPECIFIED,              MatrixCoefficients::UNSPECIFIED },
+		{ ZIMG_MATRIX_FCC,                      MatrixCoefficients::FCC },
+		{ ZIMG_MATRIX_470BG,                    MatrixCoefficients::REC_601 },
+		{ ZIMG_MATRIX_170M,                     MatrixCoefficients::REC_601 },
+		{ ZIMG_MATRIX_240M,                     MatrixCoefficients::SMPTE_240M },
+		{ ZIMG_MATRIX_YCGCO,                    MatrixCoefficients::YCGCO },
+		{ ZIMG_MATRIX_2020_NCL,                 MatrixCoefficients::REC_2020_NCL },
+		{ ZIMG_MATRIX_2020_CL,                  MatrixCoefficients::REC_2020_CL },
+		{ ZIMG_MATRIX_CHROMATICITY_DERIVED_NCL, MatrixCoefficients::CHROMATICITY_DERIVED_NCL },
+		{ ZIMG_MATRIX_CHROMATICITY_DERIVED_CL,  MatrixCoefficients::CHROMATICITY_DERIVED_CL },
+		{ ZIMG_MATRIX_ICTCP,                    MatrixCoefficients::REC_2100_ICTCP },
 	};
 	return search_itu_enum_map(map, matrix, "unrecognized matrix coefficients");
 }
@@ -228,14 +252,20 @@ zimg::colorspace::TransferCharacteristics translate_transfer(zimg_transfer_chara
 {
 	using zimg::colorspace::TransferCharacteristics;
 
-	static const zimg::static_map<zimg_transfer_characteristics_e, TransferCharacteristics, 9> map{
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_transfer_characteristics_e, TransferCharacteristics, 15> map{
 		{ ZIMG_TRANSFER_709,           TransferCharacteristics::REC_709 },
 		{ ZIMG_TRANSFER_UNSPECIFIED,   TransferCharacteristics::UNSPECIFIED },
+		{ ZIMG_TRANSFER_240M,          TransferCharacteristics::SMPTE_240M },
 		{ ZIMG_TRANSFER_601,           TransferCharacteristics::REC_709 },
+		{ ZIMG_TRANSFER_470_M,         TransferCharacteristics::REC_470_M },
+		{ ZIMG_TRANSFER_470_BG,        TransferCharacteristics::REC_470_BG },
+		{ ZIMG_TRANSFER_IEC_61966_2_4, TransferCharacteristics::XVYCC },
 		{ ZIMG_TRANSFER_IEC_61966_2_1, TransferCharacteristics::SRGB },
 		{ ZIMG_TRANSFER_2020_10,       TransferCharacteristics::REC_709 },
 		{ ZIMG_TRANSFER_2020_12,       TransferCharacteristics::REC_709 },
 		{ ZIMG_TRANSFER_LINEAR,        TransferCharacteristics::LINEAR },
+		{ ZIMG_TRANSFER_LOG_100,       TransferCharacteristics::LOG_100 },
+		{ ZIMG_TRANSFER_LOG_316,       TransferCharacteristics::LOG_316 },
 		{ ZIMG_TRANSFER_ST2084,        TransferCharacteristics::ST_2084 },
 		{ ZIMG_TRANSFER_ARIB_B67,      TransferCharacteristics::ARIB_B67 },
 	};
@@ -246,13 +276,19 @@ zimg::colorspace::ColorPrimaries translate_primaries(zimg_color_primaries_e prim
 {
 	using zimg::colorspace::ColorPrimaries;
 
-	static const zimg::static_map<zimg_color_primaries_e, ColorPrimaries, 6> map{
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_color_primaries_e, ColorPrimaries, 12> map{
+		{ ZIMG_PRIMARIES_470_M,       ColorPrimaries::REC_470_M },
+		{ ZIMG_PRIMARIES_470_BG,      ColorPrimaries::REC_470_BG },
 		{ ZIMG_PRIMARIES_709,         ColorPrimaries::REC_709 },
 		{ ZIMG_PRIMARIES_UNSPECIFIED, ColorPrimaries::UNSPECIFIED },
 		{ ZIMG_PRIMARIES_170M,        ColorPrimaries::SMPTE_C },
 		{ ZIMG_PRIMARIES_240M,        ColorPrimaries::SMPTE_C },
+		{ ZIMG_PRIMARIES_FILM,        ColorPrimaries::FILM },
 		{ ZIMG_PRIMARIES_2020,        ColorPrimaries::REC_2020 },
+		{ ZIMG_PRIMARIES_ST428,       ColorPrimaries::XYZ },
+		{ ZIMG_PRIMARIES_ST431_2,     ColorPrimaries::DCI_P3 },
 		{ ZIMG_PRIMARIES_ST432_1,     ColorPrimaries::DCI_P3_D65 },
+		{ ZIMG_PRIMARIES_EBU3213_E,   ColorPrimaries::JEDEC_P22 },
 	};
 	return search_itu_enum_map(map, primaries, "unrecognized color primaries");
 }
@@ -261,7 +297,7 @@ zimg::depth::DitherType translate_dither(zimg_dither_type_e dither)
 {
 	using zimg::depth::DitherType;
 
-	static const zimg::static_map<zimg_dither_type_e, DitherType, 4> map{
+	static SM_CONSTEXPR_14 const zimg::static_map<zimg_dither_type_e, DitherType, 4> map{
 		{ ZIMG_DITHER_NONE,            DitherType::NONE },
 		{ ZIMG_DITHER_ORDERED,         DitherType::ORDERED },
 		{ ZIMG_DITHER_RANDOM,          DitherType::RANDOM },
@@ -432,9 +468,9 @@ void zimg_get_version_info(unsigned *major, unsigned *minor, unsigned *micro)
 unsigned zimg_get_api_version(unsigned *major, unsigned *minor)
 {
 	if (major)
-		*major = static_cast<unsigned>((ZIMG_API_VERSION >> 8) & 0xFF);
+		*major = ZIMG_API_VERSION_MAJOR;
 	if (minor)
-		*minor = static_cast<unsigned>(ZIMG_API_VERSION & 0xFF);
+		*minor = ZIMG_API_VERSION_MINOR;
 
 	return ZIMG_API_VERSION;
 }
@@ -512,29 +548,49 @@ zimg_error_code_e zimg_filter_graph_process(const zimg_filter_graph *ptr, const
 	zassert_d(src, "null pointer");
 	zassert_d(dst, "null pointer");
 
-	POINTER_ALIGNMENT_ASSERT(src->plane[0].data);
-	POINTER_ALIGNMENT_ASSERT(src->plane[1].data);
-	POINTER_ALIGNMENT_ASSERT(src->plane[2].data);
-
-	STRIDE_ALIGNMENT_ASSERT(src->plane[0].stride);
-	STRIDE_ALIGNMENT_ASSERT(src->plane[1].stride);
-	STRIDE_ALIGNMENT_ASSERT(src->plane[2].stride);
-
-	POINTER_ALIGNMENT_ASSERT(dst->plane[0].data);
-	POINTER_ALIGNMENT_ASSERT(dst->plane[1].data);
-	POINTER_ALIGNMENT_ASSERT(dst->plane[2].data);
-
-	STRIDE_ALIGNMENT_ASSERT(dst->plane[0].stride);
-	STRIDE_ALIGNMENT_ASSERT(dst->plane[1].stride);
-	STRIDE_ALIGNMENT_ASSERT(dst->plane[2].stride);
-
-	POINTER_ALIGNMENT_ASSERT(tmp);
-
 	EX_BEGIN
 	const zimg::graph::FilterGraph *graph = assert_dynamic_type<const zimg::graph::FilterGraph>(ptr);
+
+	if (graph->requires_64b_alignment()) {
+		POINTER_ALIGNMENT64_ASSERT(src->plane[0].data);
+		POINTER_ALIGNMENT64_ASSERT(src->plane[1].data);
+		POINTER_ALIGNMENT64_ASSERT(src->plane[2].data);
+
+		STRIDE_ALIGNMENT64_ASSERT(src->plane[0].stride);
+		STRIDE_ALIGNMENT64_ASSERT(src->plane[1].stride);
+		STRIDE_ALIGNMENT64_ASSERT(src->plane[2].stride);
+
+		POINTER_ALIGNMENT64_ASSERT(dst->plane[0].data);
+		POINTER_ALIGNMENT64_ASSERT(dst->plane[1].data);
+		POINTER_ALIGNMENT64_ASSERT(dst->plane[2].data);
+
+		STRIDE_ALIGNMENT64_ASSERT(dst->plane[0].stride);
+		STRIDE_ALIGNMENT64_ASSERT(dst->plane[1].stride);
+		STRIDE_ALIGNMENT64_ASSERT(dst->plane[2].stride);
+
+		POINTER_ALIGNMENT64_ASSERT(tmp);
+	} else {
+		POINTER_ALIGNMENT_ASSERT(src->plane[0].data);
+		POINTER_ALIGNMENT_ASSERT(src->plane[1].data);
+		POINTER_ALIGNMENT_ASSERT(src->plane[2].data);
+
+		STRIDE_ALIGNMENT_ASSERT(src->plane[0].stride);
+		STRIDE_ALIGNMENT_ASSERT(src->plane[1].stride);
+		STRIDE_ALIGNMENT_ASSERT(src->plane[2].stride);
+
+		POINTER_ALIGNMENT_ASSERT(dst->plane[0].data);
+		POINTER_ALIGNMENT_ASSERT(dst->plane[1].data);
+		POINTER_ALIGNMENT_ASSERT(dst->plane[2].data);
+
+		STRIDE_ALIGNMENT_ASSERT(dst->plane[0].stride);
+		STRIDE_ALIGNMENT_ASSERT(dst->plane[1].stride);
+		STRIDE_ALIGNMENT_ASSERT(dst->plane[2].stride);
+
+		POINTER_ALIGNMENT_ASSERT(tmp);
+	}
+
 	auto src_buf = import_image_buffer(*src);
 	auto dst_buf = import_image_buffer(*dst);
-
 	graph->process(src_buf, dst_buf, tmp, { unpack_cb, unpack_user }, { pack_cb, pack_user });
 	EX_END
 }
