@@ -8,7 +8,7 @@
 #include "common/pixel.h"
 #include "resize/filter.h"
 #include "filtergraph.h"
-#include "basic_filter.h"
+#include "copy_filter.h"
 #include "graphbuilder.h"
 #include "image_filter.h"
 
@@ -272,7 +272,7 @@ GraphBuilder::GraphBuilder() noexcept : m_state{} {}
 
 GraphBuilder::~GraphBuilder() = default;
 
-void GraphBuilder::attach_filter(std::unique_ptr<ImageFilter> &&filter)
+void GraphBuilder::attach_filter(std::shared_ptr<ImageFilter> filter)
 {
 	if (!filter)
 		return;
@@ -280,7 +280,7 @@ void GraphBuilder::attach_filter(std::unique_ptr<ImageFilter> &&filter)
 	m_graph->attach_filter(std::move(filter));
 }
 
-void GraphBuilder::attach_filter_uv(std::unique_ptr<ImageFilter> &&filter)
+void GraphBuilder::attach_filter_uv(std::shared_ptr<ImageFilter> filter)
 {
 	if (!filter)
 		return;
@@ -371,8 +371,16 @@ void GraphBuilder::convert_depth(const PixelFormat &format, const params *params
 		.set_dither_type(dither_type)
 		.set_cpu(cpu);
 
-	FilterFactory::filter_list filter_list = factory->create_depth(conv);
-	FilterFactory::filter_list filter_list_uv;
+	for (auto &&filter : factory->create_depth(conv)) {
+		std::shared_ptr<ImageFilter> shared_filter{ std::move(filter) };
+
+		if (is_rgb(m_state)) {
+			attach_filter(shared_filter);
+			attach_filter_uv(std::move(shared_filter));
+		} else {
+			attach_filter(std::move(shared_filter));
+		}
+	}
 
 	if (is_yuv(m_state)) {
 		conv.width >>= m_state.subsample_w;
@@ -380,20 +388,11 @@ void GraphBuilder::convert_depth(const PixelFormat &format, const params *params
 		conv.pixel_in.chroma = true;
 		conv.pixel_out.chroma = true;
 
-		filter_list_uv = factory->create_depth(conv);
-	} else if (is_rgb(m_state)) {
-		for (auto &&filter : filter_list) {
-			filter = ztd::make_unique<MuxFilter>(std::move(filter));
+		for (auto &&filter : factory->create_depth(conv)) {
+			attach_filter_uv(std::move(filter));
 		}
 	}
 
-	for (auto &&filter : filter_list) {
-		attach_filter(std::move(filter));
-	}
-	for (auto &&filter : filter_list_uv) {
-		attach_filter_uv(std::move(filter));
-	}
-
 	m_state.type = format.type;
 	m_state.depth = format.depth;
 	m_state.fullrange = format.fullrange;
@@ -409,10 +408,7 @@ void GraphBuilder::convert_resize(const resize_spec &spec, const params *params,
 	ChromaLocationW chroma_location_w = spec.chroma_location_w;
 	ChromaLocationH chroma_location_h = spec.chroma_location_h;
 
-	bool image_shifted = spec.shift_w != 0.0 ||
-	                     spec.shift_h != 0.0 ||
-	                     m_state.width != spec.subwidth ||
-	                     m_state.height != spec.subheight;
+	bool image_shifted = spec.shift_w != 0.0 || spec.shift_h != 0.0 ||  m_state.width != spec.subwidth || m_state.height != spec.subheight;
 
 	if (is_greyscale(m_state)) {
 		subsample_w = 0;
@@ -445,15 +441,14 @@ void GraphBuilder::convert_resize(const resize_spec &spec, const params *params,
 	                        ((m_state.subsample_h || subsample_h) && m_state.chroma_location_h != chroma_location_h) ||
 	                        image_shifted;
 
-	FilterFactory::filter_list filter_list;
-	FilterFactory::filter_list filter_list_uv;
-
 	if (unresize && (spec.subwidth != m_state.width || spec.subheight != m_state.height))
 		error::throw_<error::ResamplingNotAvailable>("unresize not supported for given subregion");
 
 	if (do_resize_luma) {
 		double extra_shift_h = luma_shift_factor(m_state.parity, m_state.height, spec.height);
 
+		FilterFactory::filter_list filter_list;
+
 		if (unresize) {
 			auto conv = unresize::UnresizeConversion{ m_state.width, m_state.height, m_state.type }
 				.set_orig_width(spec.width)
@@ -478,9 +473,14 @@ void GraphBuilder::convert_resize(const resize_spec &spec, const params *params,
 			filter_list = factory->create_resize(conv);
 		}
 
-		if (is_rgb(m_state)) {
-			for (auto &&filter : filter_list) {
-				filter = ztd::make_unique<MuxFilter>(std::move(filter));
+		for (auto &&filter : filter_list) {
+			std::shared_ptr<ImageFilter> shared_filter{ std::move(filter) };
+
+			if (is_rgb(m_state)) {
+				attach_filter(shared_filter);
+				attach_filter_uv(std::move(shared_filter));
+			} else {
+				attach_filter(std::move(shared_filter));
 			}
 		}
 	}
@@ -496,6 +496,8 @@ void GraphBuilder::convert_resize(const resize_spec &spec, const params *params,
 		unsigned chroma_width_out = spec.width >> subsample_w;
 		unsigned chroma_height_out = spec.height >> subsample_h;
 
+		FilterFactory::filter_list filter_list_uv;
+
 		if (unresize) {
 			auto conv = unresize::UnresizeConversion{ chroma_width_in, chroma_height_in, m_state.type }
 				.set_orig_width(chroma_width_out)
@@ -519,13 +521,10 @@ void GraphBuilder::convert_resize(const resize_spec &spec, const params *params,
 
 			filter_list_uv = factory->create_resize(conv);
 		}
-	}
 
-	for (auto &&filter : filter_list) {
-		attach_filter(std::move(filter));
-	}
-	for (auto &&filter : filter_list_uv) {
-		attach_filter_uv(std::move(filter));
+		for (auto &&filter : filter_list_uv) {
+			attach_filter_uv(std::move(filter));
+		}
 	}
 
 	m_state.width = spec.width;
@@ -572,6 +571,9 @@ GraphBuilder &GraphBuilder::connect_graph(const state &target, const params *par
 
 	bool fast_f16 = cpu_has_fast_f16(params ? params->cpu : CPUClass::NONE);
 
+	if (params && cpu_requires_64b_alignment(params->cpu))
+		m_graph->set_requires_64b_alignment();
+
 	while (true) {
 		if (needs_colorspace(m_state, target)) {
 			resize_spec spec{ m_state };
