@@ -427,6 +427,8 @@ TEST(FilterGraphTest, test_support)
 		graph.attach_filter(std::move(filter2_uptr));
 		graph.complete();
 
+		graph.set_tile_width(512);
+
 		AuditImage<uint16_t> src_image{ AuditBufferType::PLANE, w, h, type, 0, 0 };
 		AuditImage<uint16_t> dst_image{ AuditBufferType::PLANE, w, h, type, 0, 0 };
 		zimg::AlignedVector<char> tmp(graph.get_tmp_size());
@@ -488,12 +490,12 @@ TEST(FilterGraphTest, test_callback)
 		EXPECT_LE(right, w);
 
 		for (unsigned ii = i; ii < i + (1 << xptr->subsample_h); ++ii) {
-			zimg::graph::ImageBuffer<uint8_t> buf = zimg::graph::static_buffer_cast<uint8_t>(xptr->buffer[0]);
+			const auto &buf = zimg::graph::static_buffer_cast<uint8_t>(xptr->buffer[0]);
 
 			std::fill(buf[ii] + left, buf[ii] + right, xptr->byte_val);
 		}
 		for (unsigned p = 1; p < 3; ++p) {
-			zimg::graph::ImageBuffer<uint8_t> chroma_buf = zimg::graph::static_buffer_cast<uint8_t>(xptr->buffer[p]);
+			const auto &chroma_buf = zimg::graph::static_buffer_cast<uint8_t>(xptr->buffer[p]);
 			unsigned i_chroma = i >> xptr->subsample_h;
 			unsigned left_chroma = (left % 2 ? left - 1 : left) >> xptr->subsample_w;
 			unsigned right_chroma = (right % 2 ? right + 1 : right) >> xptr->subsample_w;
@@ -533,6 +535,8 @@ TEST(FilterGraphTest, test_callback)
 				graph.attach_filter_uv(std::move(filter2_uptr));
 				graph.complete();
 
+				graph.set_tile_width(512);
+
 				AuditImage<uint8_t> src_image{ AuditBufferType::COLOR_RGB, w, h, type, sw, sh };
 				AuditImage<uint8_t> tmp_image{ AuditBufferType::COLOR_RGB, w, h, type, sw, sh };
 				AuditImage<uint8_t> dst_image{ AuditBufferType::COLOR_RGB, w, h, type, sw, sh };
